@@ -1,3 +1,17 @@
+# Copyright 2025 Rihaan Meher
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import argparse
 import re
 import os
@@ -9,20 +23,25 @@ import fnmatch
 
 from .parser import parse_repython
 from .cload import *
+from .tempload import *
 from textformat import *
 
+
 def compile_header_file(header_filename):
     """Compiles a .cdata file and returns the corresponding Python code."""
     header_filename = Path(header_filename).resolve()
     header_filename = str(header_filename)
     if lib.check_file_exists(header_filename.encode()) == 0:
-        raise FileNotFoundError(f"{bcolors.BOLD}{bcolors.FAIL}Header file {header_filename} not found.{bcolors.ENDC}")
+        raise FileNotFoundError(
+            f"{bcolors.BOLD}{bcolors.FAIL}Header file {header_filename} not found.{bcolors.ENDC}")
     try:
         header_code = read_file_utf8(header_filename)
         if not header_code.strip():
-            raise ValueError(f"{bcolors.BOLD}{bcolors.FAIL}Header file {header_filename} is empty.{bcolors.ENDC}")
+            raise ValueError(
+                f"{bcolors.BOLD}{bcolors.FAIL}Header file {header_filename} is empty.{bcolors.ENDC}")
     except Exception as e:
-        print(f"{bcolors.WARNING}Error opening file {header_filename}: {e}{bcolors.ENDC}")
+        print(
+            f"{bcolors.WARNING}Error opening file {header_filename}: {e}{bcolors.ENDC}")
         return ""
 
     return parse_repython(header_code)
@@ -47,16 +66,21 @@ def process_includes(code, input_file):
             header_code += compile_header_file(predefined_path) + "\n"
             continue
         # userdefined
-        if not os.path.isabs(include):
-            include = os.path.join(
-                os.path.dirname(
-                    os.path.abspath(input_file)),
-                include)
+        if not input_file == ".":
+            if not os.path.isabs(include):
+                include = os.path.join(
+                    os.path.dirname(
+                        os.path.abspath(input_file)),
+                    include)
 
         if lib.check_file_exists(include.encode()):
             header_code += compile_header_file(include) + "\n"
         else:
-            print(f"{bcolors.BOLD}{bcolors.FAIL}Error: Included file '{include}' not found.{bcolors.ENDC}")
+            print(
+                f"{
+                    bcolors.BOLD}{
+                    bcolors.FAIL}Error: Included file '{include}' not found.{
+                    bcolors.ENDC}")
             continue
 
     code_without_includes = re.sub(include_pattern, '', code)
@@ -64,18 +88,6 @@ def process_includes(code, input_file):
     return header_code, code_without_includes
 
 
-def execute_code_temporarily(code):
-    """Executes the compiled python code"""
-    with tempfile.TemporaryDirectory() as tmpdir:
-        temp_file_path = os.path.join(tmpdir, "compiled_repy.py")
-        lib.write_file(temp_file_path.encode(), code.encode())
-        try:
-            exec(open(temp_file_path).read(), {"__name__": "__main__"})
-        except Exception as e:
-            print(f"{bcolors.FAIL}Error during execution: {e}")
-            print(f"You can view the generated file at {(temp_file_path)}{bcolors.ENDC}")
-
-
 def main():
     parser = argparse.ArgumentParser(description="Compile REPY files.")
     parser.add_argument("filename", help="The REPY file to compile.")
@@ -86,7 +98,11 @@ def main():
     input_file = str(input_file)
 
     if lib.check_file_exists(input_file.encode()) == 0:
-        print(f"{bcolors.BOLD}{bcolors.FAIL}Error: The file {input_file} does not exist.{bcolors.ENDC}")
+        print(
+            f"{
+                bcolors.BOLD}{
+                bcolors.FAIL}Error: The file {input_file} does not exist.{
+                bcolors.ENDC}")
         return
     if input_file.endswith('repyconfig.toml'):
         data = load_toml_binary(input_file)
@@ -94,12 +110,14 @@ def main():
             compile_value = data["config"]["compile"]
         except BaseException:
             compile_value = "null"
-            raise BaseException(f"{bcolors.BOLD}{bcolors.FAIL}Error reading compile value from config{bcolors.ENDC}")
+            raise BaseException(
+                f"{bcolors.BOLD}{bcolors.FAIL}Error reading compile value from config{bcolors.ENDC}")
         try:
             exclude_files = data["config"]["exclude"]
         except BaseException:
             exclude_files = []
-            print(f"{bcolors.WARNING}[WARNING] No excluded files found in config{bcolors.ENDC}")
+            print(
+                f"{bcolors.WARNING}[WARNING] No excluded files found in config{bcolors.ENDC}")
         if compile_value == 'all':
             extension = ".repy"
             matching_files = []
@@ -129,7 +147,8 @@ def main():
                 print(
                     f"{bcolors.OKGREEN}Compiled {file_path_z} to {output_file_z}{bcolors.ENDC}")
     else:
-        source_code = lib.read_file(input_file.encode()).decode()
+        with open(input_file, 'r') as f:
+            source_code = f.read()
 
         header_code, code_without_includes = process_includes(
             source_code, input_file)
@@ -142,7 +161,13 @@ def main():
 
         lib.write_file(output_file.encode(), final_code.encode())
 
-        print(f"{bcolors.BOLD}{bcolors.OKGREEN}Compiled {input} to {output_file}{bcolors.ENDC}")
+        print(
+            f"{
+                bcolors.BOLD}{
+                bcolors.OKGREEN}Compiled {input_file}{
+                bcolors.ENDC}{
+                    bcolors.OKGREEN} --> {output_file}{
+                        bcolors.ENDC}")
 
 
 def launch():
@@ -154,10 +179,15 @@ def launch():
     input_file = str(input_file)
 
     if lib.check_file_exists(input_file.encode()) == 0:
-        print(f"Error: The file {input_file} does not exist.")
+        print(
+            f"{
+                bcolors.BOLD}{
+                bcolors.FAIL}Error: The file {input_file} does not exist.{
+                bcolors.ENDC}")
         return
 
-    source_code = lib.read_file(input_file.encode()).decode()
+    with open(input_file, 'r') as f:
+        source_code = f.read()
 
     header_code, code_without_includes = process_includes(
         source_code, input_file)
